@@ -5,13 +5,17 @@ import base64
 
 class simulation:
 
-    def __init__(self,token,simPath,numImages):
+    def __init__(self,token,simPath,numImages,user,nodes,name,descript,seed):
         self.token = token
         self.name = "works"
         self.numImages = numImages
+        self.simName = name
+        self.description = descript
+        self.randomSeed = seed
         self.progress = ""
         self.simID = 0
-        self.userID = 0
+        self.userID = user
+        self.nodeCount = nodes
         self.dataID = 0
         self.simPath = simPath
         self.simEncodedstr = "simEncodedstr"
@@ -28,15 +32,18 @@ class simulation:
 
         #encode the config in Base64
         with open(self.simPath) as fast:
-            simString = json.dumps(yaml.load(fast))
+            simString = json.dumps(yaml.load(fast, Loader=yaml.FullLoader))
             simEncoded = base64.b64encode(simString.encode("utf-8"))
             self.simEncodedstr = str(simEncoded, "utf-8")
 
         payload = json.dumps({
           "id": 0,
-          "userid": 1,
+          "userid": self.userID,
+          "name": self.simName,
+          "description": self.description,
           "simulationconfig": self.simEncodedstr,
-          "randomseed": 1,
+          "requestednodecount": self.nodeCount,
+          "randomseed": self.randomSeed,
           "renderjobid": 0,
           "imagecount": self.numImages
         })
@@ -75,6 +82,7 @@ class simulation:
 
         #update if sim is complete or not complete
         parseResponse = json.loads(response.text)
+        print(parseResponse)
         self.isComplete = parseResponse["isComplete"]
 
     def getDatasetItems(self):
@@ -121,6 +129,22 @@ class simulation:
         print(response.text)
         self.datasetURL = parseResponse[0]["url"]
 
+def getDatasetID(id,userToken):
+    url = "https://lexsetapi.lexset.ai/api/simulations/getsimulationstatus?id=" + str(id)
+
+    payload={}
+    headers = {
+    'Authorization': 'Bearer ' + str(userToken)
+    }
+
+    response = requests.request("GET", url, headers=headers, data=payload)
+
+    #print(response.text)
+    parseResponse = json.loads(response.text)
+    #print("Response:")
+    #print(response.text)
+    return parseResponse["datasets"][0]["id"]
+
 def listSimulations(id,userToken):
     url = "https://lexsetapi.azurewebsites.net/api/simulations/GetActiveSimulations/?userid=" + str(id)
 
@@ -160,24 +184,24 @@ def listUploads(user):
     print("uploadedFiles")
     print(response.text)
 
-def stop(simulationID):
+def stop(simulationID,token):
     url = "https://lexsetapi.azurewebsites.net/api/simulations/stopsimulation?id=" + str(simulationID)
 
     payload={}
     headers = {
-    'Authorization': 'Bearer ' + self.token
+    'Authorization': 'Bearer ' + token
     }
 
     response = requests.request("POST", url, headers=headers, data=payload)
 
     print(response.text)
 
-def start(simulationID):
+def start(simulationID,token):
     url = "https://lexsetapi.azurewebsites.net/api/Simulations/StartSimulation?id=" + str(simulationID)
 
     payload={}
     headers = {
-    'Authorization': 'Bearer ' + self.token
+    'Authorization': 'Bearer ' + token
     }
 
     response = requests.request("POST", url, headers=headers, data=payload)
